=======
nbutils
=======

Copyright (c) 2019 Jérémie DECOCK (www.jdhp.org)

* Web site: http://www.jdhp.org/software_en.html#nbutils
* Online documentation: http://nbutils.readthedocs.org
* Source code: https://github.com/jeremiedecock/python-nbutils
* Issue tracker: https://github.com/jeremiedecock/python-nbutils/issues
* nbutils on PyPI: https://pypi.python.org/pypi/nbutils


Description
===========

Python notebook utils

Note:

    This project is still in beta stage, so the API is not finalized yet.


Dependencies
============

*  Python >= 3.0

.. _install:

Installation
============

Gnu/Linux
---------

You can install, upgrade, uninstall nbutils with these commands (in a
terminal)::

    pip install --pre nbutils
    pip install --upgrade nbutils
    pip uninstall nbutils

Or, if you have downloaded the nbutils source code::

    python3 setup.py install

.. There's also a package for Debian/Ubuntu::
.. 
..     sudo apt-get install nbutils

Windows
-------

.. Note:
.. 
..     The following installation procedure has been tested to work with Python
..     3.4 under Windows 7.
..     It should also work with recent Windows systems.

You can install, upgrade, uninstall nbutils with these commands (in a
`command prompt`_)::

    py -m pip install --pre nbutils
    py -m pip install --upgrade nbutils
    py -m pip uninstall nbutils

Or, if you have downloaded the nbutils source code::

    py setup.py install

MacOSX
-------

.. Note:
.. 
..     The following installation procedure has been tested to work with Python
..     3.5 under MacOSX 10.9 (*Mavericks*).
..     It should also work with recent MacOSX systems.

You can install, upgrade, uninstall nbutils with these commands (in a
terminal)::

    pip install --pre nbutils
    pip install --upgrade nbutils
    pip uninstall nbutils

Or, if you have downloaded the nbutils source code::

    python3 setup.py install


Documentation
=============

* Online documentation: http://nbutils.readthedocs.org
* API documentation: http://nbutils.readthedocs.org/en/latest/api.html


Example usage
=============

TODO


Bug reports
===========

To search for bugs or report them, please use the nbutils Bug Tracker at:

    https://github.com/jeremiedecock/python-nbutils/issues


License
=======

This project is provided under the terms and conditions of the `MIT License`_.


.. _MIT License: http://opensource.org/licenses/MIT
.. _command prompt: https://en.wikipedia.org/wiki/Cmd.exe
